@@ -121,6 +121,23 @@ class User(models.Model):
         self.birthday = datetime.strptime(profile['birthday'], '%m/%d/%Y') if profile.has_key('birthday') else None
         
         self.save()
+    
+    @property
+    def graph(self):
+        """Return a GraphAPI instance with the user's access token."""
+        try:
+            from facepy import GraphAPI
+            return GraphAPI(self.oauth_token.token)
+        except ImportError:
+            pass
+            
+        try:
+            from facebook import GraphAPI
+            return GraphAPI(self.oauth_token.token)
+        except ImportError:
+            pass
+        
+        raise ImportError('Neither Facepy nor Facebook-SDK could be imported')
         
     def __unicode__(self):
         if self.full_name:
